"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createLogger = void 0;
const fs = require("fs");
const path = require("path");
const winston_1 = require("winston");
const { combine, printf, timestamp } = winston_1.format;
const logFormat = printf(({ level, message, timestamp }) => {
    return `${timestamp} [${level}] ${message}`;
});
const createLogger = (createLogFiles, outputDir) => {
    const transports = [
        new winston_1.transports.Console({}),
    ];
    const dir = path.resolve(outputDir || ".");
    if (!fs.existsSync(dir))
        throw new Error("output directory does not exist");
    if (createLogFiles)
        transports.push(new winston_1.transports.File({
            filename: `${dir}/${new Date().toISOString()}.log`,
            options: { flags: "w" },
        }));
    return winston_1.createLogger({
        level: process.env.LOG_LEVEL || "info",
        format: combine(timestamp(), logFormat),
        transports,
    });
};
exports.createLogger = createLogger;
